==> huaweicloudsdkcbr-3.0.53-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/policy_trigger_resp.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PolicyTriggerResp:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'name': 'str',
        'properties': 'PolicyTriggerPropertiesResp',
        'type': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'properties': 'properties',
        'type': 'type'
    }

    def __init__(self, id=None, name=None, properties=None, type=None):
        """PolicyTriggerResp - a model defined in huaweicloud sdk"""
        
        

        self._id = None
        self._name = None
        self._properties = None
        self._type = None
        self.discriminator = None

        self.id = id
        if name is not None:
            self.name = name
        self.properties = properties
        if type is not None:
            self.type = type

    @property
    def id(self):
        """Gets the id of this PolicyTriggerResp.

        调度器id

        :return: The id of this PolicyTriggerResp.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PolicyTriggerResp.

        调度器id

        :param id: The id of this PolicyTriggerResp.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """Gets the name of this PolicyTriggerResp.

        调度器名称

        :return: The name of this PolicyTriggerResp.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PolicyTriggerResp.

        调度器名称

        :param name: The name of this PolicyTriggerResp.
        :type: str
        """
        self._name = name

    @property
    def properties(self):
        """Gets the properties of this PolicyTriggerResp.


        :return: The properties of this PolicyTriggerResp.
        :rtype: PolicyTriggerPropertiesResp
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this PolicyTriggerResp.


        :param properties: The properties of this PolicyTriggerResp.
        :type: PolicyTriggerPropertiesResp
        """
        self._properties = properties

    @property
    def type(self):
        """Gets the type of this PolicyTriggerResp.

        调度器类型,目前只支持 time: 定时调度。

        :return: The type of this PolicyTriggerResp.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PolicyTriggerResp.

        调度器类型,目前只支持 time: 定时调度。

        :param type: The type of this PolicyTriggerResp.
        :type: str
        """
        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PolicyTriggerResp):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcbr-3.0.73-py2.py3-none-any.whl: huaweicloudsdkcbr/v1/model/policy_trigger_resp.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PolicyTriggerResp:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'id': 'str',
        'name': 'str',
        'properties': 'PolicyTriggerPropertiesResp',
        'type': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'properties': 'properties',
        'type': 'type'
    }

    def __init__(self, id=None, name=None, properties=None, type=None):
        """PolicyTriggerResp - a model defined in huaweicloud sdk"""
        
        

        self._id = None
        self._name = None
        self._properties = None
        self._type = None
        self.discriminator = None

        self.id = id
        if name is not None:
            self.name = name
        self.properties = properties
        if type is not None:
            self.type = type

    @property
    def id(self):
        """Gets the id of this PolicyTriggerResp.

        调度器id

        :return: The id of this PolicyTriggerResp.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PolicyTriggerResp.

        调度器id

        :param id: The id of this PolicyTriggerResp.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """Gets the name of this PolicyTriggerResp.

        调度器名称

        :return: The name of this PolicyTriggerResp.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PolicyTriggerResp.

        调度器名称

        :param name: The name of this PolicyTriggerResp.
        :type: str
        """
        self._name = name

    @property
    def properties(self):
        """Gets the properties of this PolicyTriggerResp.


        :return: The properties of this PolicyTriggerResp.
        :rtype: PolicyTriggerPropertiesResp
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this PolicyTriggerResp.


        :param properties: The properties of this PolicyTriggerResp.
        :type: PolicyTriggerPropertiesResp
        """
        self._properties = properties

    @property
    def type(self):
        """Gets the type of this PolicyTriggerResp.

        调度器类型,目前只支持 time: 定时调度。

        :return: The type of this PolicyTriggerResp.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PolicyTriggerResp.

        调度器类型,目前只支持 time: 定时调度。

        :param type: The type of this PolicyTriggerResp.
        :type: str
        """
        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PolicyTriggerResp):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
